@@ -5,15 +5,15 @@ from copy import deepcopy
 import pytest
 from tornado import gen
 
-from distributed.client import _wait
+from distributed.client import wait
 from distributed.diagnostics.eventstream import EventStream, eventstream
 from distributed.metrics import time
 from distributed.utils_test import div, gen_cluster
 
 
-@gen_cluster(client=True, ncores=[('127.0.0.1', 1)] * 3)
+@gen_cluster(client=True, ncores=[("127.0.0.1", 1)] * 3)
 def test_eventstream(c, s, *workers):
-    pytest.importorskip('bokeh')
+    pytest.importorskip("bokeh")
 
     es = EventStream()
     s.add_plugin(es)
@@ -21,24 +21,25 @@ def test_eventstream(c, s, *workers):
 
     futures = c.map(div, [1] * 10, range(10))
     total = c.submit(sum, futures[1:])
-    yield _wait(total)
-    yield _wait(futures)
+    yield wait(total)
+    yield wait(futures)
 
     assert len(es.buffer) == 11
 
     from distributed.bokeh import messages
     from distributed.diagnostics.progress_stream import task_stream_append
-    lists = deepcopy(messages['task-events']['rectangles'])
+
+    lists = deepcopy(messages["task-events"]["rectangles"])
     workers = dict()
     for msg in es.buffer:
         task_stream_append(lists, msg, workers)
 
-    assert len([n for n in lists['name'] if n.startswith('transfer')]) == 2
-    for name, color in zip(lists['name'], lists['color']):
-        if name == 'transfer':
-            assert color == 'red'
+    assert len([n for n in lists["name"] if n.startswith("transfer")]) == 2
+    for name, color in zip(lists["name"], lists["color"]):
+        if name == "transfer":
+            assert color == "red"
 
-    assert any(c == 'black' for c in lists['color'])
+    assert any(c == "black" for c in lists["color"])
 
 
 @gen_cluster(client=True)
@@ -57,7 +58,7 @@ def test_eventstream_remote(c, s, a, b):
     total = []
     while len(total) < 10:
         msgs = yield comm.read()
-        assert isinstance(msgs, list)
+        assert isinstance(msgs, tuple)
         total.extend(msgs)
         assert time() < start + 5
 
